from .lazy_evaluation import pipe_j_lazy_to_py_callbacks
from ..base import BatchOperatorWrapper
from ...common.types.bases.j_obj_wrapper import JavaObjectWrapper
from ...common.types.conversion.java_method_call import auto_convert_java_type
from ...common.types.conversion.type_converters import j_value_to_py_value
from ...common.utils.printing import print_with_title


class WithTrainInfo(JavaObjectWrapper):
    def getTrainInfoBatchOp(self):
        return BatchOperatorWrapper(self.get_j_obj().getTrainInfoBatchOp())

    def lazyPrintTrainInfo(self, title=None):
        return self.lazyCollectTrainInfo(lambda d: print_with_title(d, title))

    @auto_convert_java_type
    def collectTrainInfo(self):
        return self.collectTrainInfo()

    def lazyCollectTrainInfo(self, *callbacks):
        pipe_j_lazy_to_py_callbacks(
            self.get_j_obj().lazyCollectTrainInfo,
            callbacks,
            j_value_to_py_value
        )
        return self
